==> kubernetes-client-5.1.2-sources.jar: io/fabric8/kubernetes/client/handlers/certificates/v1beta1/CertificateSigningRequestHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.certificates.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.certificates.v1beta1.CertificateSigningRequestOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest;
import io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class CertificateSigningRequestHandler implements ResourceHandler<CertificateSigningRequest, CertificateSigningRequestBuilder> {

  @Override
  public String getKind() {
    return CertificateSigningRequest.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "certificates.k8s.io/v1beta1";
      }

  @Override
  public CertificateSigningRequest create(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public CertificateSigningRequest replace(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public CertificateSigningRequest reload(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public CertificateSigningRequestBuilder edit(CertificateSigningRequest item) {
    return new CertificateSigningRequestBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, CertificateSigningRequest item) {
    return new CertificateSigningRequestOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, Watcher<CertificateSigningRequest> watcher) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, String resourceVersion, Watcher<CertificateSigningRequest> watcher) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, ListOptions options, Watcher<CertificateSigningRequest> watcher) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public CertificateSigningRequest waitUntilReady(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public CertificateSigningRequest waitUntilCondition(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, Predicate<CertificateSigningRequest> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-5.3.0-sources.jar: io/fabric8/kubernetes/client/handlers/certificates/v1beta1/CertificateSigningRequestHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.certificates.v1beta1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.certificates.v1beta1.CertificateSigningRequestOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest;
import io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class CertificateSigningRequestHandler implements ResourceHandler<CertificateSigningRequest, CertificateSigningRequestBuilder> {

  @Override
  public String getKind() {
    return CertificateSigningRequest.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "certificates.k8s.io/v1beta1";
      }

  @Override
  public CertificateSigningRequest create(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, boolean dryRun) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).dryRun(dryRun).create();
  }

  @Override
  public CertificateSigningRequest replace(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, boolean dryRun) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).dryRun(dryRun).replace(item);
  }

  @Override
  public CertificateSigningRequest reload(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public CertificateSigningRequestBuilder edit(CertificateSigningRequest item) {
    return new CertificateSigningRequestBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, long gracePeriodSeconds, CertificateSigningRequest item, boolean dryRun) {
    return new CertificateSigningRequestOperationsImpl(client, config, namespace).withItem(item).dryRun(dryRun).withPropagationPolicy(propagationPolicy).withGracePeriod(gracePeriodSeconds).delete();
  }

@Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, Watcher<CertificateSigningRequest> watcher) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, String resourceVersion, Watcher<CertificateSigningRequest> watcher) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, ListOptions options, Watcher<CertificateSigningRequest> watcher) {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public CertificateSigningRequest waitUntilReady(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public CertificateSigningRequest waitUntilCondition(OkHttpClient client, Config config, String namespace, CertificateSigningRequest item, Predicate<CertificateSigningRequest> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new CertificateSigningRequestOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
